@@ -21,9 +21,11 @@ import sys
 import types
 import warnings
 
-str_and_sequence_types = (str if str is not bytes else basestring, list, tuple)
 
-class ShowSwitch(object):
+str_and_sequence_types = (str, list, tuple)
+
+
+class ShowSwitch:
     """Simple stack-based switch."""
 
     def __init__(self):
@@ -42,15 +44,16 @@ class ShowSwitch(object):
         return self.stack == []
 
     def __repr__(self):
-        return '<ShowSwitch %s>' %(self() and 'on' or 'off')
+        return '<ShowSwitch %s>' % (self() and 'on' or 'off')
 
 
-# This attribute can be used to temporarly deactivate deprecation
+# This attribute can be used to temporarily deactivate deprecation
 # warnings, so that backward-compatibility code can import other
-# backward-compatiblity components without warnings being produced.
+# backward-compatibility components without warnings being produced.
 __show__ = ShowSwitch()
 
-class Suppressor(object):
+
+class Suppressor:
 
     def __enter__(self):
         __show__.off()
@@ -58,8 +61,11 @@ class Suppressor(object):
     def __exit__(self, *ignored):
         __show__.on()
 
+
 ogetattr = object.__getattribute__
-class DeprecationProxy(object):
+
+
+class DeprecationProxy:
 
     def __init__(self, module):
         self.__original_module = module
@@ -99,7 +105,8 @@ class DeprecationProxy(object):
 
         delattr(self.__original_module, name)
 
-class DeprecatedModule(object):
+
+class DeprecatedModule:
 
     def __init__(self, module, msg, cls=DeprecationWarning):
         self.__original_module = module
@@ -129,7 +136,8 @@ class DeprecatedModule(object):
             return object.__delattr__(self, name)
         delattr(self.__original_module, name)
 
-class DeprecatedGetProperty(object):
+
+class DeprecatedGetProperty:
 
     def __init__(self, prop, message, cls=DeprecationWarning):
         self.message = message
@@ -141,6 +149,7 @@ class DeprecatedGetProperty(object):
             warnings.warn(self.message, self.cls, 2)
         return self.prop.__get__(inst, klass)
 
+
 class DeprecatedGetSetProperty(DeprecatedGetProperty):
 
     def __set__(self, inst, prop):
@@ -148,6 +157,7 @@ class DeprecatedGetSetProperty(DeprecatedGetProperty):
             warnings.warn(self.message, self.cls, 2)
         self.prop.__set__(inst, prop)
 
+
 class DeprecatedGetSetDeleteProperty(DeprecatedGetSetProperty):
 
     def __delete__(self, inst):
@@ -155,6 +165,7 @@ class DeprecatedGetSetDeleteProperty(DeprecatedGetSetProperty):
             warnings.warn(self.message, self.cls, 2)
         self.prop.__delete__(inst)
 
+
 def DeprecatedMethod(method, message, cls=DeprecationWarning):
 
     def deprecated_method(*args, **kw):
@@ -164,6 +175,7 @@ def DeprecatedMethod(method, message, cls=DeprecationWarning):
 
     return deprecated_method
 
+
 def deprecated(specifier, message, cls=DeprecationWarning):
     """Deprecate the given names."""
 
@@ -178,7 +190,6 @@ def deprecated(specifier, message, cls=DeprecationWarning):
             sys.modules[modname] = DeprecationProxy(sys.modules[modname])
         sys.modules[modname].deprecate(specifier, message, cls)
 
-
     # Anything else can mean the specifier is a function/method,
     # module, or just an attribute of a class
     elif isinstance(specifier, types.FunctionType):
@@ -188,14 +199,15 @@ def deprecated(specifier, message, cls=DeprecationWarning):
     else:
         prop = specifier
         if hasattr(prop, '__get__') and hasattr(prop, '__set__') and \
-               hasattr(prop, '__delete__'):
+                hasattr(prop, '__delete__'):
             return DeprecatedGetSetDeleteProperty(prop, message, cls)
         elif hasattr(prop, '__get__') and hasattr(prop, '__set__'):
             return DeprecatedGetSetProperty(prop, message, cls)
         elif hasattr(prop, '__get__'):
             return DeprecatedGetProperty(prop, message, cls)
 
-class deprecate(object):
+
+class deprecate:
     """Deprecation decorator"""
 
     def __init__(self, msg, cls=DeprecationWarning):
@@ -205,11 +217,12 @@ class deprecate(object):
     def __call__(self, func):
         return DeprecatedMethod(func, self.msg, self.cls)
 
+
 def moved(to_location, unsupported_in=None, cls=DeprecationWarning):
     old = sys._getframe(1).f_globals['__name__']
-    message = '%s has moved to %s.' % (old, to_location)
+    message = '{} has moved to {}.'.format(old, to_location)
     if unsupported_in:
-        message += " Import of %s will become unsupported in %s" % (
+        message += " Import of {} will become unsupported in {}".format(
             old, unsupported_in)
 
     warnings.warn(message, cls, 3)
